@@ -4,7 +4,7 @@ sentry.conf.server
 
 These settings act as the default (base) settings for the Sentry-provided web-server
 
-:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -128,5 +128,10 @@ import logging
 logger = logging.getLogger()
 logger.setLevel(logging.ERROR)
 
+# Disable django.request as it's generally useless
+logger = logging.getLogger('django.request')
+logger.propagate = False
+
+
 # Configure default sentry logging
 setup_logging(SentryHandler())
